'''
/*****************************************************************************************************
*                                   NOTICE
*
* THIS COMPUTER SOFTWARE CONTAINS PROPRIETARY INFORMATION OF USDA-ARS/ALARC.
* NEITHER RECEIPT NOR POSSESSION THEREOF COVERS ANY RIGHT TO
* REPRODUCE OR USE, OR DISCLOSE IN WHOLE OR IN PART, ANY SUCH INFORMATION
* WITHOUT WRITTEN AUTHORIZATION FROM USDA-ARS/SWMRU.  
* 
* ****************************************************************************************************
* Program: Pic2Video
* ****************************************************************************************************
* Purpose: Generating a Video File from Pictures
* Author: James Kim (james.kim2@usda.gov)
* Version:  V1.0
* Date:  2019-11-19  
* Revision:  
* ****************************************************************************************************/
'''
import os
import tkinter as tk #cf)Tkinter for Python 2.*
from tkinter import filedialog,simpledialog
import cv2

class Dialog_Input4Vid(simpledialog.Dialog):
    def __init__(self,parent, title=None, entry_to_clear=None):     
        tk.simpledialog.Dialog.__init__(self, parent, title) 
    def body(self, parent):
        self.lb1 = tk.Label(parent, text="Zoom factor : ")
        self.lb1.grid(row=0,sticky=tk.W)
        self.e1 = tk.Entry(parent, width=4)
        self.e1.grid(row=0,column=1,sticky=tk.W)
        self.e1.insert(0,'.25')
        tk.Label(parent, text="fps : ").grid(row=1,sticky=tk.W)
        self.e2 = tk.Entry(parent, width=4)
        self.e2.grid(row=1,column=1,sticky=tk.W)
        self.e2.insert(0,'15')
        self.zf = self.fps = 0

    def apply(self):
        if self.e1.get()=="": self.zf = 1
        else: self.zf = float(self.e1.get()) # 25%
        if self.e2.get()=="": self.fps = 30
        else: self.fps = float(self.e2.get()) # 15 

# Load and convert image files to a video files
def Pic2Video(src_dir,zf=None,fps=None):
    print('src_dir=',src_dir)          
    dst_dir = src_dir[:src_dir.rfind(src_dir.split('/')[-1])]
    basename = src_dir.split('/')[-1] 
    print('dst_dir=',dst_dir,'basename=',basename)                
    if zf==None: zf = .1    # zoom factor
    if fps==None: fps = 30    # frame/sec
    
    #Detect # of files, W, H
    num_file = 0
    for i,filename in enumerate(os.listdir(src_dir)):
        fname = filename.lower()        
        if fname.endswith('.tif') or fname.endswith('.jpg') or fname.endswith('.bmp') or fname.endswith('.png'):
            num_file = num_file + 1
            if num_file == 1:
                print(src_dir+'/'+filename)
                im = cv2.imread(src_dir+'/'+filename)    
                H, W, Ch = im.shape                                            
    print('WxH=',W,H,'=>',int(W*zf),int(H*zf))

    # create a video output
    out = cv2.VideoWriter(dst_dir+'/'+basename+'.avi',cv2.VideoWriter_fourcc(*'DIVX'), fps, (int(W*zf), int(H*zf)))
    # save a video output
    for i,filename in enumerate(os.listdir(src_dir)):
        if i== 0: print (num_file,end=" files:")                
        if num_file>=10 and i%(int(num_file/10)) == 0: print("-",end="") 
        
        fname = filename.lower()
        if fname.endswith('.tif') or fname.endswith('.jpg') or fname.endswith('.bmp') or fname.endswith('.png'):
            Datestamp = "%s/%s/%s"%(fname[5:7],fname[7:9],fname[:4])
            #print('fname=',fname,'Datestamp=',Datestamp)
            im = cv2.imread(src_dir+'/'+filename)
            
            H, W, Ch = im.shape       
            if zf == 1:
                # add date stamp in the image
                font = cv2.FONT_HERSHEY_SIMPLEX
                cv2.putText(im,Datestamp, (5,40), font, .5, (255,0,0), 2, cv2.LINE_AA)  #(,,(i,j),font,size,color(B,G,R),thickness,)            
                #cv2.imshow('im=',im), cv2.waitKey(0)

                out.write(im)
            else:
                im_zf = cv2.resize(im, (int(W*zf), int(H*zf)))
                # add date stamp in the image
                font = cv2.FONT_HERSHEY_SIMPLEX
                cv2.putText(im_zf,Datestamp, (5,40), font, .5, (255,0,0), 2, cv2.LINE_AA)  #(,,(i,j),font,size,color(B,G,R),thickness,)            
                #cv2.imshow('im_zf=',im_zf), cv2.waitKey(0)

                out.write(im_zf)
    out.release()        
    print('done')
    

if __name__ == '__main__':
    root = tk.Tk()
    #fdir = os.path.dirname(os.path.realpath(__file__))
    #print('fdir=',fdir)
    src_dir = tk.filedialog.askdirectory()        
    
    d = Dialog_Input4Vid(root)
    print('d.zf=',d.zf,'d.fps=',d.fps)
    if d.zf != 0 and d.fps !=0:
        zf = d.zf
        fps = d.fps          
        Pic2Video(src_dir,zf,fps)
    